PCB Environment: Window Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Slots | Public Member Functions
Window Class Reference
Inheritance diagram for Window:

## Public Slots
void | terminate ()

## Public Member Functions
| Window (UIApplication &)
ActionTab * | getActionTab () const
ParameterTab * | getParameterTab () const
GLWidget * | getGLWidget () const
void | setPCB (const std::shared_ptr< PCBoard > &)
UIApplication * | getApplication () const
void | keyPressEvent (QKeyEvent *) override
void | keyReleaseEvent (QKeyEvent *) override

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Window.hpp